| construct_adj_mat | R Documentation |
For an item pool with N items, this returns an N x N matrix. The diagonal
elements contain the number of times each item has been administered. The
off-diagonal element (i, j) contains the number of respondents who have
been administered both item i and item j. In general this function
is not called directly, but is instead called within meow(). It is exposed
to aid users who are testing item selection functions they have written.
construct_adj_mat(admin)
admin |
An administration matrix with one row per respondent and one
column per item. Non-zero entries indicate that an item has been
administered to a respondent (see |
An item-item adjacency matrix of type matrix.
admin <- matrix(c(1, 1, 0,
1, 0, 1), nrow = 2, byrow = TRUE)
construct_adj_mat(admin)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.