| data_existing | R Documentation |
data_existing() is a wrapper for three separate calls to read.csv() that packages the output into the object used by meow().
data_existing(resp_path, pers_path, item_path)
resp_path |
A file path to a long form .csv file. File should have three columns, |
pers_path |
A file path to a wide form .csv file that contains true person parameter values, with one person per row. Include a person index column, named |
item_path |
A file path to a wide form .csv file that contains true item parameter values, with one item per row. Include an item index column, named |
A list with three components: A dataframe of item response named resp, a dataframe of true person parameters named pers_tru, and a dataframe of true item parameters named item_tru
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.