| select_max_dist_enhanced | R Documentation |
Extends select_max_dist() with a flexible edge weight calculation.
select_max_dist_enhanced(
pers,
item,
R,
admin,
adj_mat = NULL,
n_candidates = 1,
edge_weight_fun = edge_weight_inverse,
edge_weight_args = list()
)
pers |
A data frame of current respondent ability estimates. |
item |
A data frame of current item parameter estimates. |
R |
A respondent-by-item matrix of potential responses. |
admin |
An integer administration matrix; |
adj_mat |
An item-item adjacency matrix. See |
n_candidates |
The number of farthest items to assemble into a candidate pool before selecting the next item by maximum information. Allows users to trade off network density against estimation efficiency. |
edge_weight_fun |
A function that computes edge weights from the
adjacency matrix. See |
edge_weight_args |
A named list of additional arguments for
|
An updated administration matrix with the selected item marked for each respondent.
sim <- meow(select_max_dist_enhanced, update_theta_mle, data_simple_1pl,
data_args = list(N_persons = 10, N_items = 10), fix = "item",
select_args = list(edge_weight_fun = edge_weight_power))
nrow(sim$results)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.