| select_max_info | R Documentation |
Administers the remaining item with the highest information for each respondent, computed from the current parameter estimates and a 2PL item response function.
select_max_info(pers, item, R, admin, adj_mat = NULL)
pers |
A data frame of current respondent ability estimates. |
item |
A data frame of current item parameter estimates. |
R |
A respondent-by-item matrix of potential responses. |
admin |
An integer administration matrix; |
adj_mat |
An item-item adjacency matrix. See |
An updated administration matrix with the most informative remaining item marked for each respondent.
sim <- meow(select_max_info, update_theta_mle, data_simple_1pl,
data_args = list(N_persons = 10, N_items = 10), fix = "item")
nrow(sim$results)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.