View source: R/update-parameters.R
| update_theta_mle | R Documentation |
This update function treats item parameters as fixed and known and updates person ability estimates after each iteration with a maximum likelihood estimate based on a 2PL item response function.
update_theta_mle(pers, item, R, admin)
pers |
A data frame of current respondent parameter estimates. |
item |
A data frame of item parameter values. |
R |
A respondent-by-item matrix of potential responses. |
admin |
An integer administration matrix; non-zero entries indicate
administered items. See |
A list with two entries: pers, a data frame with updated respondent
ability estimates, and item, the unchanged data frame of item parameters.
data <- data_simple_1pl(N_persons = 10, N_items = 10)
admin <- matrix(0L, 10, 10)
admin[, 1:5] <- 1L
R <- matrix(data$resp$resp, nrow = 10, byrow = TRUE)
upd <- update_theta_mle(data$pers_tru, data$item_tru, R, admin)
head(upd$pers)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.